bodyfat: Percentage of Body Fat Dataset

bodyfatR Documentation

Percentage of Body Fat Dataset

Description

Percentage of body fat measurements from individuals assisted in a public hospital in Curitiba, Paraná, Brazil.

Usage

bodyfat

Format

A data frame with 298 observations and 9 variables:

  • ARMS: arms fat percentage.

  • LEGS: legs fat percentage.

  • BODY: body fat percentage.

  • ANDROID: android fat percentage.

  • GYNECOID: gynoid fat percentage.

  • AGE: age of individuals.

  • BMI: body mass index.

  • SEX: 1 for female and 2 for male.

  • IPAQ: physical activity level according to IPAQ (0 = sedentary, 1 = insufficiently active, 2 = active).

Author(s)

Josmar Mazucheli jmazucheli@gmail.com

Bruna Alves pg402900@uem.br

References

Mazucheli, J., Alves, B., Korkmaz, M. Ç., and Leiva, V. (2022). Vasicek quantile and mean regression models for bounded data: New formulation, mathematical derivations, and numerical applications. Mathematics, 10, 1389.

Mazucheli, J., Leiva, V., Alves, B., and Menezes, A. F. B. (2021). A new quantile regression for modeling bounded data under a unit Birnbaum-Saunders distribution with applications in medicine and politics. Symmetry, 13(4), 1–21.

Petterle, R. R., Bonat, W. H., Scarpin, C. T., Jonasson, T., and Borba, V. Z. C. (2020). Multivariate quasi-beta regression models for continuous bounded data. The International Journal of Biostatistics, 17(1), 39–53.

Examples

data(bodyfat, package = "vasicekreg")

bodyfat$AGE <- bodyfat$AGE - 46.00
bodyfat$BMI <- bodyfat$BMI - 24.72
bodyfat$SEX <- as.factor(bodyfat$SEX)
bodyfat$IPAQ<- as.factor(bodyfat$IPAQ)

library(gamlss)

## Mean regression model
fitmean <- gamlss(
  ARMS ~ AGE + BMI + SEX + IPAQ,
  data = bodyfat,
  family = NVASIM(mu.link = "logit", sigma.link = "logit")
)

## Not run: 
tau_levels <- c(0.10, 0.25, 0.50, 0.75, 0.90)

## Quantile regression models with the normal kernel
fit_normal <- lapply(tau_levels, function(Tau) {
  tau <<- Tau
  gamlss(
    ARMS ~ AGE + BMI + SEX + IPAQ,
    data = bodyfat,
    family = NVASIQ(
      mu.link = "logit",
      sigma.link = "logit"
    )
  )
})

## Quantile regression models with the logistic kernel
fit_logistic <- lapply(tau_levels, function(Tau) {
  tau <<- Tau
  gamlss(
    ARMS ~ AGE + BMI + SEX + IPAQ,
    data = bodyfat,
    family = LVASIQ(
      mu.link = "logit",
      sigma.link = "logit"
    )
  )
})

lapply(fit_normal, summary)
lapply(fit_logistic, summary)

## End(Not run)

vasicekreg documentation built on Aug. 20, 2026, 9:08 a.m.